#!/usr/bin/env python
# coding: utf8


# Importation des biblothèques

import wx
import wx.lib.buttons
import serial
import time



# Instanciation et initialisation du port série

portCom = serial.Serial()
portCom.port = '/dev/ttyACM0'
portCom.baudrate = 115200

# Dérivation d'une instance de la classe wx.Frame

class FBase(wx.Frame): 
	def __init__(self, parent, title):
		wx.Frame.__init__(self, parent, title=title, size=(227,168))
		self.Show(True)					

		# Gestion des exceptions : ici, on teste un éventuel problème de liaison série
		
		try:
			portCom.open()
		except serial.SerialException:
			import Dialog1 
			dlg = Dialog1.Dialog1(self)
			try:
				dlg.ShowModal()
			finally:
				dlg.Destroy()	
		
		# Création des wxWidgets : ici, 3 boutons (wxButton)  et 1 voyant (wxStaticBitmap)		
		
		allumerBtn = wx.Button(self, wx.ID_ANY, "Allumer", pos=(16, 16), size=(86, 31))		
		eteindreBtn = wx.Button(self, wx.ID_ANY, "Éteindre", pos=(16, 56), size=(86, 31))		
		quitterBtn = wx.Button(self, wx.ID_ANY, "Quitter", pos=(128, 96), size=(86, 31))		
		voyant = wx.StaticBitmap(self, wx.ID_ANY, bitmap = wx.Bitmap("voyant_off.png",
						wx.BITMAP_TYPE_PNG), pos=(152, 32), size=(32, 32), style=0, name="voyant")				
					
		# Définition des fonctions générales : ici, une seule fonction	
				 		
		def majLed(commande):
			portCom.write(commande)
			time.sleep(0.1)
			nbCar = portCom.in_waiting
			retour = portCom.read(nbCar)
			if (retour == "ledOn"):
				bitmap = wx.Bitmap("voyant_on.png",wx.BITMAP_TYPE_PNG)
			else:
				bitmap = wx.Bitmap("voyant_off.png",wx.BITMAP_TYPE_PNG)
			voyant.SetBitmap(bitmap)
		
		# Définition des gestionnaires d'évènement
		
		def onAllumerBtn(event):
			majLed("on")
			
		def onEteindreBtn(event):
			majLed("off")
			
		def onQuitterBtn(event):
			self.Close()
		
		# Connexion entre les boutons et leur gestionnaire d'évènement respectif
			
		allumerBtn.Bind(wx.EVT_BUTTON, onAllumerBtn, allumerBtn)
		eteindreBtn.Bind(wx.EVT_BUTTON, onEteindreBtn, eteindreBtn)	
		quitterBtn.Bind(wx.EVT_BUTTON, onQuitterBtn, quitterBtn)		
		

# Lancement de l'application

app = wx.App(False)
frame = FBase(None, "Commande LED")
app.MainLoop()
